@@ -7,7 +7,7 @@ extern GtkWidget *partyline_page_new (void);
 extern void partyline_connectstatus (int status);
 extern void partyline_namelabel (char *nick, char *team);
 extern void partyline_status (char *status);
-extern void partyline_text (char *text);
+extern void partyline_text (const gchar *text);
 extern void partyline_fmt (const char *text, ...) G_GNUC_PRINTF (1, 2);
 extern void partyline_playerlist (int *numbers, char **names, char **teams, int n, char **specs, int sn);
 extern void partyline_entryfocus (void);
